@@ -4,6 +4,10 @@
 #include "global.h"
 #include <QMediaPlayer>
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 namespace Ui {
     class VMailDialog;
 }
